# acto
Automate Common Tasks On-demand.

![](https://img.shields.io/pypi/v/acto?label=acto&color=blue&cacheSeconds=60)

## Install

```sh
pip install acto --upgrade
```

## Usage

Run example:

```sh
python -m acto.times
python -m acto.tests
```